@@ -9,8 +9,7 @@
 #' @param label a length-\eqn{n} vector of data class labels.
 #' @param ndim an integer-valued target dimension.
 #' @param preprocess an additional option for preprocessing the data.
-#' Default is "center" and other options of "decorrelate" and "whiten"
-#' are supported. See also \code{\link{aux.preprocess}} for more details.
+#' Default is "center". See also \code{\link{aux.preprocess}} for more details.
 #'
 #' @return a named list containing
 #' \describe{
@@ -43,7 +42,7 @@
 #' @author Kisung You
 #' @rdname linear_LQMI
 #' @export
-do.lqmi  <- function(X, label, ndim=2, preprocess=c("center","whiten","decorrelate")){
+do.lqmi  <- function(X, label, ndim=2, preprocess=c("center","scale","cscale","whiten","decorrelate")){
   #------------------------------------------------------------------------
   ## PREPROCESSING
   #   1. data matrix
@@ -80,10 +79,9 @@ do.lqmi  <- function(X, label, ndim=2, preprocess=c("center","whiten","decorrela
 
   #------------------------------------------------------------------------
   ## COMPUTATION : PRELIMINARY
-  tmplist = aux.preprocess(X,type=algpreprocess)
+  tmplist = aux.preprocess.hidden(X,type=algpreprocess,algtype="linear")
   trfinfo = tmplist$info
   pX      = tmplist$pX
-  trfinfo$algtype = "linear"
 
   #------------------------------------------------------------------------
   ## COMPUTATION : MAIN STEPS FOR LQMI
